@@ -86,6 +86,10 @@ setMethod('raster', signature(x='BasicRaster'),
 	function(x) {
 		e <- x@extent
 		r <- raster(xmn=e@xmin, xmx=e@xmax, ymn=e@ymin, ymx=e@ymax, nrows=x@nrows, ncols=x@ncols, crs=x@crs)
+		if (x@rotated) {
+			r@rotated <- TRUE
+			r@rotation <- x@rotation
+		}
 		return(r)
 	}
 )
@@ -115,6 +119,11 @@ setMethod('raster', signature(x='RasterStack'),
 			projection(r) <- projection(x)
 		}
 		extent(r) <- extent(x) # perhaps it was changed by user and different on disk
+		if (x@layers[[1]]@rotated) {
+			r@rotated <- TRUE
+			r@rotation <- x@layers[[1]]@rotation
+		}
+		
 		return(r)
 	}
 )
@@ -184,6 +193,12 @@ setMethod('raster', signature(x='RasterBrick'),
 		} else {
 			r <- raster(extent(x), nrows=nrow(x), ncols=ncol(x), crs=projection(x))	
 		}
+
+		if (x@rotated) {
+			r@rotated <- TRUE
+			r@rotation <- x@rotation
+		}
+	
 		return(r)
 	}
 )
